##
# Classifier 表示模式识别分类器。

module Unidom::Stapar
  class Classifier < ApplicationRecord

    self.table_name = 'unidom_classifiers'

    include Unidom::Common::Concerns::ModelExtension
    include ProgneTapera::EnumCode

    validates :supplier_name,       presence: true, length: { in: 2..self.columns_hash['supplier_name'].limit }
    validates :algorithm_name,      presence: true, length: { in: 2..self.columns_hash['algorithm_name'].limit }
    validates :data_format_version, presence: true, numericality: { greater_than: 0, less_than_or_equal_to: Unidom::Common::MAXIMUM_AMOUNT, only_integer: true }
    validates :applied_species,     presence: true, length: { in: 2..self.columns_hash['applied_species'].limit }

    has_many :features, class_name: 'Unidom::Stapar::Feature'

    code :applied_field, Unidom::Stapar::AppliedField

    scope :supplier_name_is,       -> (supplier_name)       { where supplier_name:       supplier_name       }
    scope :algorithm_name_is,      -> (algorithm_name)      { where algorithm_name:      algorithm_name      }
    scope :data_format_version_is, -> (data_format_version) { where data_format_version: data_format_version }
    scope :applied_species_is,     -> (applied_species)     { where applied_species:     applied_species     }

  end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::Classifier'
end
