# Feature 表示特征记录。

module Unidom::Stapar
  class Feature < ApplicationRecord

    self.table_name = 'unidom_features'

    include Unidom::Common::Concerns::ModelExtension
    include ProgneTapera::EnumCode
    include Unidom::Stapar::Concerns::AsFeature
    include Unidom::Stapar::Concerns::AsPattern
    include Unidom::Stapar::Concerns::AsInputFeature
    include Unidom::Stapar::Concerns::AsMatchedFeature

    validates :extracted_link,      presence: true, length: { in: 4..self.columns_hash['extracted_link'].limit }
    validates :extracted_mime_type, presence: true, length: { in: 4..self.columns_hash['extracted_mime_type'].limit }
    validates :extracted_file_size, presence: true, numericality: { greater_than_or_equal_to: -1, less_than_or_equal_to: Unidom::Common::MAXIMUM_AMOUNT, only_integer: true }

    validates :feature_link,      presence: true, length: { in: 4..self.columns_hash['feature_link'].limit }
    validates :feature_mime_type, presence: true, length: { in: 4..self.columns_hash['feature_mime_type'].limit }
    validates :feature_file_size, presence: true, numericality: { greater_than_or_equal_to: -1, less_than_or_equal_to: Unidom::Common::MAXIMUM_AMOUNT, only_integer: true }

    scope :extracted_link_is, -> (extracted_link) { where extracted_link: extracted_link    }
    scope :feature_link_is,   -> (feature_link)   { where feature_link:   feature_link      }

  end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::Feature'
end
