##
# Pattern Library 表示模式库。

module Unidom::Stapar
  class PatternLibrary < ApplicationRecord

    self.table_name = 'unidom_pattern_libraries'

    include Unidom::Common::Concerns::ModelExtension
    include ProgneTapera::EnumCode

    belongs_to :subject,           polymorphic: true
    belongs_to :matched_processor, polymorphic: true

    validates :name,             presence: true, length:       { in: 2..self.columns_hash['name'].limit }
    validates :valve_percentage, presence: true, numericality: { greater_than: 0, less_than_or_equal_to: 100, only_integer: true }
    validates :applied_species,  presence: true, length:       { in: 2..self.columns_hash['applied_species'].limit }

    code :applied_field, Unidom::Stapar::AppliedField

    scope :subject_is,           -> (subject)           { where subject:           subject           }
    scope :matched_processor_is, -> (matched_processor) { where matched_processor: matched_processor }

  end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::PatternLibrary'
end
