##
# Pattern Matching 表示模式识别匹配记录。

module Unidom::Stapar
  class PatternMatching < ApplicationRecord

    self.table_name = 'unidom_pattern_matchings'

    include Unidom::Common::Concerns::ModelExtension
    include ProgneTapera::EnumCode

    belongs_to :matched, polymorphic: true
    belongs_to :input,   polymorphic: true

    validates :similarity_percentage, presence: true, numericality: { greater_than: 0, less_than_or_equal_to: 100 }
    validates :valve_percentage,      presence: true, numericality: { greater_than: 0, less_than_or_equal_to: 100, only_integer: true }

    scope :matched_is, -> (matched) { where matched: matched }
    scope :input_is,   -> (input)   { where input:   input   }

    def self.match!(input, matched: nil, with: 0.0, above: 0, at: Time.now)
      create! matched: matched, input: input, valve_percentage: above, similarity_percentage: with, opened_at: at
    end

  end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::PatternMatching'
end
