require 'rails_helper'

describe Unidom::Stapar::Feature, type: :model do

  before :each do
  end

  after :each do
  end

  context do

    classifier = Unidom::Stapar::Classifier.first_or_create! supplier_name: 'Intelligent Works',
      algorithm_name:      'FR Pro',
      data_format_version: 1,
      applied_species:     'Homo sapiens',
      applied_field_code:  'FACE'
    substance       = classifier
    taker_equipment = classifier

    sample = Unidom::Stapar::Sample.first_or_create! substance_id: substance.id,
      substance_type:       substance.class.name,
      taker_equipment_id:   taker_equipment.id,
      taker_equipment_type: taker_equipment.class.name,
      raw_data_link:        'https://objectstore/substances/{substance_id}/samples/{id}.jpg',
      raw_data_mime_type:   'image/jpeg',
      raw_data_file_size:   1.megabytes,
      sampled_at:           Time.now

    model_attributes = {
      sample_id:           sample.id,
      classifier_id:       classifier.id,
      extracted_link:      'https://objectstore/{id}/extracted/{sequence}.jpg',
      extracted_mime_type: 'image/jpeg',
      extracted_file_size: 64.kilobytes,
      feature_link:        'https://objectstore/{id}/feature/{sequence}.bin',
      feature_mime_type:   'application/octet-stream',
      feature_file_size:   2.kilobytes,
      grade:               60
    }

    it_behaves_like 'Unidom::Common::Concerns::ModelExtension', model_attributes

    it_behaves_like 'validates text', model_attributes, :extracted_link,
      length: 4..described_class.columns_hash['extracted_link'].limit
    it_behaves_like 'validates text', model_attributes, :extracted_mime_type,
      length: 4..described_class.columns_hash['extracted_mime_type'].limit
    it_behaves_like 'validates numericality', model_attributes, :extracted_file_size,
      range: -1..Unidom::Common::MAXIMUM_AMOUNT, minimum_inclusive: true, maximum_inclusive: true, only_integer: true

    it_behaves_like 'validates text', model_attributes, :feature_link,
      length: 4..described_class.columns_hash['feature_link'].limit
    it_behaves_like 'validates text', model_attributes, :feature_mime_type,
      length: 4..described_class.columns_hash['feature_mime_type'].limit
    it_behaves_like 'validates numericality', model_attributes, :feature_file_size,
      range: -1..Unidom::Common::MAXIMUM_AMOUNT, minimum_inclusive: true, maximum_inclusive: true, only_integer: true

    #it_behaves_like 'validates numericality', model_attributes, :grade,
    #  range: 0..Unidom::Common::MAXIMUM_AMOUNT, minimum_inclusive: true, maximum_inclusive: true, only_integer: true

  end

end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::Feature'
