require 'rails_helper'

describe Unidom::Stapar::Sample, type: :model do

  before :each do
  end

  after :each do
  end

  context do

    classifier = Unidom::Stapar::Classifier.first_or_create! supplier_name: 'Intelligent Works',
      algorithm_name:      'FR Pro',
      data_format_version: 1,
      applied_species:     'Homo sapiens',
      applied_field_code:  'FACE'
    substance       = classifier
    taker_equipment = classifier

    model_attributes = {
      substance_id:         substance.id,
      substance_type:       substance.class.name,
      taker_equipment_id:   taker_equipment.id,
      taker_equipment_type: taker_equipment.class.name,
      raw_data_link:        'https://objectstore/substances/{substance_id}/samples/{id}.jpg',
      raw_data_mime_type:   'image/jpeg',
      raw_data_file_size:   1.megabytes,
      sampled_at:           Time.now,
    }

    it_behaves_like 'Unidom::Common::Concerns::ModelExtension', model_attributes

    it_behaves_like 'validates text', model_attributes, :raw_data_link,
      length: 4..described_class.columns_hash['raw_data_link'].limit
    it_behaves_like 'validates text', model_attributes, :raw_data_mime_type,
      length: 4..described_class.columns_hash['raw_data_mime_type'].limit
    it_behaves_like 'validates numericality', model_attributes, :raw_data_file_size,
      range: -1..Unidom::Common::MAXIMUM_AMOUNT, minimum_inclusive: true, maximum_inclusive: true, only_integer: true

  end

end unless Unidom::Common::Neglection.namespace_neglected? 'Unidom::Stapar::Sample'
